import {NgModule} from '@angular/core';
import {PreloadAllModules, RouterModule, Routes} from '@angular/router';
import {OpenaireErrorPageComponent} from './error/errorPage.component';
import {PageURLResolverComponent} from "./openaireLibrary/utils/pageURLResolver.component";

const routes: Routes = [
  // Other Pages
  {path: '', loadChildren: './home/home.module#HomeModule'},
  //{ path: 'home', loadChildren: './home/home.module#HomeModule'},
  {path: 'home', redirectTo: '', pathMatch: 'full'},
  {path: 'mail-preferences', loadChildren: './userEmailPreferences/mailPrefs.module#LibMailPrefsModule'},
  // ORCID Pages
  {path: 'orcid', loadChildren: './orcid/orcid.module#LibOrcidModule'},
  // {
  //   path: 'recommended-orcid-links',
  //   loadChildren: './orcid/recommend-orcid-links/searchRecommendedResultsForOrcid.module#LibSearchRecommendedResultsForOrcidModule'
  // },
  {path: 'my-orcid-links', loadChildren: './orcid/my-orcid-links/myOrcidLinks.module#LibMyOrcidLinksModule'},
  // Landing Pages
  {path: 'search/result', loadChildren: './landingPages/result/libResult.module#LibResultModule'},
  {path: 'search/publication', loadChildren: './landingPages/publication/libPublication.module#LibPublicationModule'},
  {path: 'search/dataset', loadChildren: './landingPages/dataset/libDataset.module#LibDatasetModule'},
  {path: 'search/software', loadChildren: './landingPages/software/libSoftware.module#LibSoftwareModule'},
  {path: 'search/other', loadChildren: './landingPages/orp/libOrp.module#LibOrpModule'},
  {path: 'search/project', loadChildren: './landingPages/project/libProject.module#LibProjectModule'},
  {
    path: 'search/dataprovider',
    loadChildren: '././landingPages/dataProvider/libDataProvider.module#LibDataProviderModule'
  },
  {
    path: 'search/organization',
    loadChildren: './landingPages/organization/libOrganization.module#LibOrganizationModule'
  },
  {
    path: 'project-report',
    loadChildren: './landingPages/htmlProjectReport/libHtmlProjectReport.module#LibHtmlProjectReportModule'
  },
  // Search Pages
  {path: 'search/find', loadChildren: './searchPages/find/libSearch.module#LibMainSearchModule'},
  {
    path: 'search/find/research-outcomes',
    loadChildren: './searchPages/simple/searchResearchResults.module#OpenaireSearchResearchResultsModule'
  },
  {path: 'search/find/publications', component: PageURLResolverComponent},
  {path: 'search/find/datasets', component: PageURLResolverComponent},
  {path: 'search/find/software', component: PageURLResolverComponent},
  {path: 'search/find/other', component: PageURLResolverComponent},
  {path: 'search/find/projects', loadChildren: './searchPages/simple/searchProjects.module#LibSearchProjectsModule'},
  {
    path: 'search/find/dataproviders',
    loadChildren: './searchPages/simple/searchDataProviders.module#LibSearchDataProvidersModule'
  },
  {
    path: 'search/find/organizations',
    loadChildren: './searchPages/simple/searchOrganizations.module#LibSearchOrganizationsModule'
  },
  // Advanced Search Pages
  {
    path: 'search/advanced/research-outcomes',
    loadChildren: './searchPages/advanced/searchResearchResults.module#OpenaireAdvancedSearchResearchResultsModule'
  },
  {path: 'search/advanced/publications', component: PageURLResolverComponent},
  {path: 'search/advanced/datasets', component: PageURLResolverComponent},
  {path: 'search/advanced/software', component: PageURLResolverComponent},
  {path: 'search/advanced/other', component: PageURLResolverComponent},
  {
    path: 'search/advanced/organizations',
    loadChildren: './searchPages/advanced/advancedSearchOrganizations.module#LibAdvancedSearchOrganizationsModule'
  },
  {
    path: 'search/advanced/dataproviders',
    loadChildren: './searchPages/advanced/advancedSearchDataProviders.module#LibAdvancedSearchDataProvidersModule'
  },
  {
    path: 'search/advanced/projects',
    loadChildren: './searchPages/advanced/advancedSearchProjects.module#LibAdvancedSearchProjectsModule'
  },
  // Search Content Providers Pages
  {
    path: 'search/content-providers',
    loadChildren: './searchPages/dataProviders/compatibleDataProviders.module#LibCompatibleDataProvidersModule'
  },
  {path: 'search/content-providers-table', redirectTo: 'search/content-providers'},
  {
    path: 'search/entity-registries',
    loadChildren: './searchPages/dataProviders/entityRegistries.module#LibEntityRegistriesModule'
  },
  {path: 'search/entity-registries-table', redirectTo: 'search/entity-registries'},
  {path: 'search/journals', loadChildren: './searchPages/dataProviders/journals.module#LibJournalsModule'},
  {path: 'search/journals-table', redirectTo: 'search/journals'},
  // Deposit Pages
  {path: 'participate/deposit-datasets', redirectTo: 'participate/deposit/learn-how', pathMatch: 'full'},
  {path: 'participate/deposit-datasets-result', redirectTo: 'participate/deposit/learn-how', pathMatch: 'full'},
  {path: 'participate/deposit-subject-result', redirectTo: 'participate/deposit/learn-how', pathMatch: 'full'},
  {path: 'participate/deposit-publications', redirectTo: 'participate/deposit/learn-how', pathMatch: 'full'},
  {path: 'participate/deposit-publications-result', redirectTo: 'participate/deposit/learn-how', pathMatch: 'full'},
  {path: 'participate/deposit/learn-how', loadChildren: './deposit/deposit.module#LibDepositModule'},
  {
    path: 'participate/deposit/search',
    loadChildren: './deposit/searchDataprovidersToDeposit.module#LibSearchDataprovidersToDepositModule'
  },
  // Linking Pages
  {path: 'myclaims', loadChildren: './claims/myClaims/myClaims.module#LibMyClaimsModule'},
  {path: 'claims', loadChildren: './claims/claimsAdmin/claimsAdmin.module#LibClaimsAdminModule'},
  {path: 'participate/claim', loadChildren: './claims/linking/linkingGeneric.module#LibLinkingGenericModule'},
  {
    path: 'participate/direct-claim',
    loadChildren: './claims/directLinking/directLinking.module#LibDirectLinkingModule'
  },
  // { path: 'claims-project-manager', loadChildren: './claims/claimsByToken/claimsByToken.module#LibClaimsByTokenModule'},
  // help pages - do not exist in Admin portal/api/db
  {path: 'reload', loadChildren: './reload/libReload.module#LibReloadModule'},
  {path: 'user-info', loadChildren: './login/libUser.module#LibUserModule'},
  {path: 'error', component: OpenaireErrorPageComponent},
  {path: '**', pathMatch: 'full', component: OpenaireErrorPageComponent}
];

@NgModule({
  imports: [RouterModule.forRoot(routes, {
    onSameUrlNavigation: "reload",
    relativeLinkResolution: 'corrected'
  })],
  exports: [RouterModule]
})
export class AppRoutingModule {
}
